
:LastChangedDate: $LastChangedDate$
:LastChangedRevision: $LastChangedRevision$
:LastChangedBy: $LastChangedBy$

Developer Guides
================

.. toctree::
   :hidden:

   web-overview
   using-twistedweb
   web-development
   twisted-templates
   xmlrpc
   web-in-60/index
   resource-templates
   client
   glossary


- Introduction

  - :doc:`Overview of Twisted Web <web-overview>`

- Web Applications

  - :doc:`Using twisted.web <using-twistedweb>`
  - :doc:`Web application development <web-development>`
  - :doc:`HTML Templating with twisted.web.template <twisted-templates>`
  - :doc:`XML-RPC and SOAP <xmlrpc>`
  - :doc:`Twisted Web in 60 Seconds: A series of short, complete examples using twisted.web <web-in-60/index>`
  - :doc:`Quixote resource templates <resource-templates>`

- Other

  - :doc:`Using the Twisted Web Client <client>`

- Appendix

  - :doc:`Glossary <glossary>`
